@@ -1,8 +1,8 @@
 # frozen_string_literal: true
 
 module Git
-  class Remote < Path
-
+  # A remote in a Git repository
+  class Remote
     attr_accessor :name, :url, :fetch_opts
 
     def initialize(base, name)
@@ -13,7 +13,7 @@ module Git
       @fetch_opts = config['fetch']
     end
 
-    def fetch(opts={})
+    def fetch(opts = {})
       @base.fetch(@name, opts)
     end
 
@@ -35,6 +35,5 @@ module Git
     def to_s
       @name
     end
-
   end
 end
